# Gaussian Distribution Package
Python package for Binomial and Gaussian distribution.


## Table of Contents
1. [Project Motivation](###project-motivation)
2. [Licensing, Authors, and Acknowledgements](###licensing,-authors,-and-acknowledgements)
3. [Installation](###Installation)
4. [Usage](###Usage)
5. [Licensing and Acknowledgements](###Licensing-and-Acknowledgements)



### Project Motivation
Start contributing to the python pypi package. The package computes the Binomial and Gaussian for list of numbers.

### Installation
The following libraries meke the dependencies for the package
* Python3
* matplotlib
Installation of the package is available [here]()

```
pip install 
```

### Usage

### Licensing and Acknowledgements
Credit is due to Udacity Data Scientist NanoDegree Program!